@@ -1,9 +1,9 @@
 package Sah::Schemas::Chrome;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-07-19'; # DATE
+our $DATE = '2021-07-20'; # DATE
 our $DIST = 'Sah-Schemas-Chrome'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 1;
 # ABSTRACT: Various Sah schemas related to Google Chrome
@@ -20,13 +20,7 @@ Sah::Schemas::Chrome - Various Sah schemas related to Google Chrome
 
 =head1 VERSION
 
-This document describes version 0.002 of Sah::Schemas::Chrome (from Perl distribution Sah-Schemas-Chrome), released on 2021-07-19.
-
-=head1 CONTRIBUTOR
-
-=for stopwords perlancar (on pc-home)
-
-perlancar (on pc-home) <perlancar@gmail.com>
+This document describes version 0.003 of Sah::Schemas::Chrome (from Perl distribution Sah-Schemas-Chrome), released on 2021-07-20.
 
 =head1 SAH SCHEMAS
 
